// Copyright 2024 Matthew Rich <matthewrich.conf@gmail.com>. All rights reserved.
 
package main

import (
  "io"
  "fmt"
  "strings"
  "testing"
  "github.com/stretchr/testify/assert"
  "golang.org/x/net/html"
)

/*
<meta name="title" content="Yahoo Finance - Stock Market Live, Quotes, Business &amp; Finance News">
<meta name="description" content="At Yahoo Finance, you get free stock quotes, up-to-date news, portfolio management resources, international market data, social interaction and mortgage rates that help you manage your financial life.">
<meta name="keywords" content="401k, Business, Financial Information, Investing, Investor, Market News, Stock Research, Stock Valuation, business news, economy, finance, investment tools, mortgage, mutual funds, personal finance, quote, real estate, retirement, stock, stocks, Suze Orman, tax, track portfolio">
<meta http-equiv="x-dns-prefetch-control" content="on">
<meta name="theme-color" content="#037B66">
<meta name="oath:guce:consent-host" content="guce.yahoo.com">
<meta property="twitter:dnt" content="on">
<meta name="twitter:site" content="@YahooFinance">
<meta property="fb:app_id" content="458584288257241">
<meta property="fb:pages" content="458584288257241">
<meta property="og:image" content="https://s.yimg.com/cv/apiv2/social/images/yahoo_default_logo.png">
<meta property="og:description" content="At Yahoo Finance, you get free stock quotes, up-to-date news, portfolio management resources, international market data, social interaction and mortgage rates that help you manage your financial life.">
<meta property="og:title" content="Yahoo Finance - Stock Market Live, Quotes, Business &amp; Finance News">
<meta property="twitter:description" content="At Yahoo Finance, you get free stock quotes, up-to-date news, portfolio management resources, international market data, social interaction and mortgage rates that help you manage your financial life.">
<meta property="twitter:title" content="Yahoo Finance - Stock Market Live, Quotes, Business &amp; Finance News">
<meta property="al:ios:app_store_id" content="328412701">
<meta property="al:ios:app_name" content="Yahoo Finance">
<meta property="al:android:url" content="intent://#Intent;scheme=yfinance;action=android.intent.action.VIEW;package=com.yahoo.mobile.client.android.finance;S.browser_fallback_url=https%3A%2F%2Fplay.google.com%2Fstore%2Fapps%2Fdetails%3Fid%3Dcom.yahoo.mobile.client.android.finance;end">
<meta property="al:android:app_name" content="Yahoo Finance">
<meta property="al:android:package" content="com.yahoo.mobile.client.android.finance">
<meta property="apple-itunes-app" content="app-id=328412701, app-clip-bundle-id=com.yahoo.finance.clip-qsp, affiliate-data=ct=us.fin.mbl.smart-banner&pt=9029, app-argument=https://yfinance.onelink.me/3068494570?pid=AppPromo&c=US_Acquisition_YMktg_337__&af_sub1=Acquisition&af_sub2=US_YMktg&af_sub3=&af_sub4=100000591&af_sub5=SmartBanner__SmartBanner_">


*/
func TestExtractUrl(t *testing.T) {
  htmlData := `
<html><head>
<meta name="title" content="Yahoo Finance - Stock Market Live, Quotes, Business &amp; Finance News">
<meta name="description" content="At Yahoo Finance, you get free stock quotes, up-to-date news, portfolio management resources, international market data, social interaction and mortgage rates that help you manage your financial life.">
<meta name="keywords" content="401k, Business, Financial Information, Investing, Investor, Market News, Stock Research, Stock Valuation, business news, economy, finance, investment tools, mortgage, mutual funds, personal finance, quote, real estate, retirement, stock, stocks, Suze Orman, tax, track portfolio">
<meta name="theme-color" content="#037B66">
</head><body></body></html>`

  reader := io.NopCloser(strings.NewReader(htmlData))

  meta, _ := extractTagsMetaDataFromUrl(reader)
  assert.Greater(t, len(meta), 0)
  assert.Contains(t, meta, "international")
  assert.Contains(t, meta, "401k")
}

func TestHtmlFile(t *testing.T) {
  htmlData := `
<html><head>
<meta name="title" content="Yahoo Finance - Stock Market Live, Quotes, Business &amp; Finance News">
<meta name="description" content="At Yahoo Finance, you get free stock quotes, up-to-date news, portfolio management resources, international market data, social interaction and mortgage rates that help you manage your financial life.">
<meta name="keywords" content="401k, Business, Financial Information, Investing, Investor, Market News, Stock Research, Stock Valuation, business news, economy, finance, investment tools, mortgage, mutual funds, personal finance, quote, real estate, retirement, stock, stocks, Suze Orman, tax, track portfolio">
<meta name="theme-color" content="#037B66">
</head><body></body></html>`

  reader := io.NopCloser(strings.NewReader(htmlData))
  doc,_ := html.Parse(reader)

  v := (*htmlNode)(doc).Find("head").FindAll("meta")

  for i := 0; i < len(v); i++ {
    fmt.Printf("%#v\n", v[i].Data)
  }
  assert.Equal(t, 4, len(v))
}
