// Copyright 2024 Matthew Rich <matthewrich.conf@gmail.com>. All rights reserved.
 
package stream

import (
_ "fmt"
  "io"
  "testing"
  "net/http"
  "net/http/httptest"

  "github.com/gin-gonic/gin"
  "github.com/stretchr/testify/assert"
_ "encoding/json"
_ "strings"
)
 
func TestStreamRecorder(t *testing.T) {
  r := NewRecorder()
  if r == nil {
    t.Errorf("Failed creating new recorder")
  }
  if r.CloseNotify() == nil {
    t.Errorf("Failed creating CloseNotify channel")
  }
}

func TestStreamClose(t *testing.T) {
  r := NewRecorder()
  go r.Close()

  select {
  case flag, open := <-r.CloseNotify():
    if flag && open {
      return
    }
  }
  t.Errorf("Failed to close the stream close channel")
}

func TestStream(t *testing.T) {
  r := NewRecorder()
  request := httptest.NewRequest(http.MethodGet, "/test", nil)

  g := gin.New()
  g.Handle(http.MethodGet, "/test", func(c *gin.Context){
    c.Stream(func(w io.Writer) bool { c.SSEvent("message", "msg"); return false })
    <-c.Writer.CloseNotify()
  })

  go g.ServeHTTP(r, request)

  

  for !r.Flushed {}

  r.Close()
  assert.Equal(t, r.Body.String(), "event:message\ndata:msg\n\n")
}
