// Copyright 2024 Matthew Rich <matthewrich.conf@gmail.com>. All rights reserved.
 
package client

import (
  "fmt"
  "testing"
  "github.com/stretchr/testify/assert"
  "net/http"
  "net/http/httptest"
_ "strings"
)

func TestNewClient(t *testing.T) {
  cli := New("http://localhost:8080")
  assert.NotEqual(t, nil, cli)
}

func TestClientConnection(t *testing.T) {
  server := httptest.NewServer(http.HandlerFunc(func(rw http.ResponseWriter, req *http.Request) {
    assert.Equal(t, req.URL.String(), "/api/v1/ping")
    rw.Write([]byte(`pong`))
  }))

  defer server.Close()

  cli := New(fmt.Sprintf("%s/api/v1", server.URL))
  e := cli.Ping()
  assert.Equal(t, nil, e)
}

/*
func TestClientDecodeJsonResponse(t *testing.T) {
  cli := New()
  statusJsonDocument := strings.NewReader(`{"status": "success"}`)

  v := cli.decodeJsonResponse(statusJsonDocument)
  assert.Greater(t, 0, len(v))
}
*/

func TestClientAddTagResource(t *testing.T) {                                                                                                                                                                   
  server := httptest.NewServer(http.HandlerFunc(func(rw http.ResponseWriter, req *http.Request) {
    assert.Equal(t, req.URL.String(), "/api/v1/tags/finance")
    rw.Write([]byte(`{ "status": "success" }`))
  }))

  defer server.Close()


  cli := New(fmt.Sprintf("%s/api/v1", server.URL))

  err := cli.AddTagResource("finance", "https://finance.yahoo.com")
  assert.Equal(t, nil, err)
}
