// Copyright 2024 Matthew Rich <matthewrich.conf@gmail.com>. All rights reserved.
 
package data

import (
  "context"
  "github.com/redis/go-redis/v9"
)

type MockRedisClient struct {
  InjectPing func(ctx context.Context) *redis.StatusCmd
  InjectLRange func(ctx context.Context, key string, start, stop int64) *redis.StringSliceCmd
  InjectSInter func(ctx context.Context, keys ...string) *redis.StringSliceCmd
  InjectKeys func(ctx context.Context, pattern string) *redis.StringSliceCmd
  InjectSAdd func(ctx context.Context, key string, members ...interface{}) *redis.IntCmd
  InjectSIsMember func(ctx context.Context, key string, member interface{}) *redis.BoolCmd
}

func (m *MockRedisClient) Ping(ctx context.Context) *redis.StatusCmd {
  if m.InjectPing == nil {
    return redis.NewStatusCmd(ctx, "ping") 
  }
  return m.InjectPing(ctx)
}

func (m *MockRedisClient) LRange(ctx context.Context, key string, start, stop int64) *redis.StringSliceCmd {
  return m.InjectLRange(ctx, key, start, stop)
}

func (m *MockRedisClient) SInter(ctx context.Context, keys ...string) *redis.StringSliceCmd {
  return m.InjectSInter(ctx, keys...)
}

func (m *MockRedisClient) Keys(ctx context.Context, pattern string) *redis.StringSliceCmd {
  return m.InjectKeys(ctx, pattern)
}

func (m *MockRedisClient) SAdd(ctx context.Context, key string, members ...interface{}) *redis.IntCmd {
  return m.InjectSAdd(ctx, key, members...)
}

func (m *MockRedisClient) SIsMember(ctx context.Context, key string, member interface{}) *redis.BoolCmd {
  return m.InjectSIsMember(ctx, key, member)
}
