// Copyright 2024 Matthew Rich <matthewrich.conf@gmail.com>. All rights reserved.
 
package service

import (
  "context"
)

type MockDataConnector struct {
  InjectConnected func(context.Context) bool
  InjectQuery func(context.Context, []string) ([]string, error)
  InjectTags func(context.Context) []string
  InjectAddTag func(context.Context, string, string) error
  InjectResourceHasTag func(context.Context, string, string) bool
}

func (m *MockDataConnector) Connected(ctx context.Context) bool {
  if m.InjectConnected == nil {
    return true
  }
  return m.InjectConnected(ctx)
}

func (m *MockDataConnector) Query(ctx context.Context, terms []string) ([]string, error) {
  return m.InjectQuery(ctx, terms)
}

func (m *MockDataConnector) Tags(ctx context.Context) []string {
  return m.InjectTags(ctx)
}

func (m *MockDataConnector) AddTag(ctx context.Context, TagName string, Resource string) error {
  return m.InjectAddTag(ctx, TagName, Resource)
}

func (m *MockDataConnector) ResourceHasTag(ctx context.Context, TagName string, Resource string) bool {
  return m.InjectResourceHasTag(ctx, TagName, Resource)
}
