// Copyright 2024 Matthew Rich <matthewrich.conf@gmail.com>. All rights reserved.
 
package mocks

import (
  "context"
)

type MockDataConnector struct {
  InjectConnected func(context.Context) bool
  InjectQuery func(context.Context, []string) ([]string, error)
  InjectTags  func(context.Context) []string
  InjectAddTag func(context.Context, string, string) error
  InjectResourceHasTag func(context.Context, string, string) bool
}

func (m *MockDataConnector) Connected(context context.Context) bool {
  if m.InjectConnected == nil {
    return true
  }
  return m.InjectConnected(context)
}

func (m *MockDataConnector) Query(context context.Context, terms []string) ([]string, error) {
  return m.InjectQuery(context, terms)
}

func (m *MockDataConnector) Tags(context context.Context) []string {
  return m.InjectTags(context)
}

func (m *MockDataConnector) AddTag(context context.Context, TagName string, Resource string) error {
  return m.InjectAddTag(context, TagName, Resource)
}

func (m *MockDataConnector) ResourceHasTag(context context.Context, Resource string, TagName string) bool {
  return m.InjectResourceHasTag(context, Resource, TagName)
}
